@@ -1,13 +1,13 @@
 from django.contrib import admin
 
 from django_common_utils.libraries.fieldsets import DefaultAdminMixin
-from django_common_utils.libraries.fieldsets.mixins import TitleAdminFieldsetMixin
+from django_common_utils.libraries.fieldsets.mixins import SlugAdminFieldsetMixin, TitleAdminFieldsetMixin
 from .models import Article
 
 
 class ArticleAdmin(DefaultAdminMixin):
     mixins = [
-        TitleAdminFieldsetMixin,
+        TitleAdminFieldsetMixin, SlugAdminFieldsetMixin
     ]
     fieldset_fields = {
         "default": ["...!"]
