@@ -1,11 +1,14 @@
 from typing import *
 
 __all__ = [
-    "ensure_iteration", "ensure_dict"
+    "ensure_iteration", "ensure_dict", "combine_fields"
 ]
 
 
 # https://stackoverflow.com/a/3655857/9878135
+from django_common_utils.libraries.handlers import HandlerDefinitionType
+
+
 def islambda(x, /) -> bool:
     lambda_func = lambda: 0
     return isinstance(x, type(lambda_func)) and x.__name__ == lambda_func.__name__
@@ -32,3 +35,4 @@ def ensure_dict(value: dict, key_type, value_type) -> Generator[Tuple[Any, Any],
         for key in ensure_iteration(key_unknown, key_type):
             for value in ensure_iteration(value_unknown, value_type):
                 yield key, value
+
